@@ -1,11 +1,17 @@
 package test
 
 import (
+	"bytes"
 	"context"
 	"fmt"
+	"io/ioutil"
+	"net/http"
+	"path/filepath"
+	"text/template"
 	"time"
 
 	framework "github.com/operator-framework/operator-sdk/pkg/test"
+	"github.com/pkg/errors"
 	v1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -20,6 +26,7 @@ import (
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/components"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/network"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/check"
+	"github.com/kubevirt/cluster-network-addons-operator/test/kubectl"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/okd"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/operations"
 )
@@ -336,8 +343,141 @@ var _ = Describe("NetworkAddonsConfig", func() {
 			})
 		})
 	})
+	Describe("NMState", func() {
+		var (
+			configSpec cnao.NetworkAddonsConfigSpec
+		)
+		BeforeEach(func() {
+			configSpec = cnao.NetworkAddonsConfigSpec{
+				NMState: &cnao.NMState{},
+			}
+		})
+		JustBeforeEach(func() {
+			// Install nmstate-operator here
+			installNMStateOperator()
+			CheckNMStateOperatorIsReady(5 * time.Minute)
+
+			CreateConfig(gvk, configSpec)
+			CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, CheckDoNotRepeat)
+		})
+		JustAfterEach(func() {
+			uninstallNMStateOperator()
+		})
+		Context("when it is already deployed", func() {
+			Context("and the nmstate-operator is installed", func() {
+				It("should run nmstate from the operator", func() {
+					By("checking for NMState in nmstate namespace")
+					Eventually(func() error {
+						nmstateHandlerDaemonSet := &v1.DaemonSet{}
+						return framework.Global.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
+					}, 5*time.Minute, time.Second).Should(BeNil(), fmt.Sprintf("Timed out waiting for nmstate-operator daemonset"))
+				})
+			})
+		})
+		Context("when it is not already deployed", func() {
+			BeforeEach(func() {
+				configSpec = cnao.NetworkAddonsConfigSpec{}
+			})
+			Context("and the nmstate-operator is installed", func() {
+				It("should run nmstate from the operator", func() {
+					configSpec = cnao.NetworkAddonsConfigSpec{
+						NMState: &cnao.NMState{},
+					}
+					UpdateConfig(gvk, configSpec)
+					CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, CheckDoNotRepeat)
+					By("checking for NMState in nmstate namespace")
+					Eventually(func() error {
+						nmstateHandlerDaemonSet := &v1.DaemonSet{}
+						return framework.Global.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
+					}, 5*time.Minute, time.Second).Should(BeNil(), fmt.Sprintf("Timed out waiting for nmstate-operator daemonset"))
+				})
+			})
+		})
+	})
 })
 
+func installNMStateOperator() {
+	By("Installing kubernetes-nmstate-operator")
+	componentSource, err := GetComponentSource("nmstate")
+	Expect(err).ToNot(HaveOccurred(), "Error getting the component source")
+
+	result, err := kubectl.Kubectl("apply", "-f", fmt.Sprintf("https://raw.githubusercontent.com/nmstate/kubernetes-nmstate/%s/deploy/crds/nmstate.io_nmstates.yaml", componentSource.Metadata))
+	Expect(err).ToNot(HaveOccurred(), "Error applying CRD: %s", result)
+
+	// Create temp directory
+	tmpdir, err := ioutil.TempDir("", "operator-test")
+	Expect(err).ToNot(HaveOccurred(), "Error creating temporary dir")
+	manifests := []string{"namespace", "service_account", "role", "role_binding", "operator"}
+	for _, manifest := range manifests {
+		yamlString, err := parseManifest(fmt.Sprintf("https://raw.githubusercontent.com/nmstate/kubernetes-nmstate/%s/deploy/operator/%s.yaml", componentSource.Metadata, manifest), componentSource.Metadata)
+		Expect(err).ToNot(HaveOccurred(), fmt.Sprintf("Error parsing manifest file to string: %s", manifest))
+
+		yamlFile := filepath.Join(tmpdir, fmt.Sprintf("%s.yaml", manifest))
+		ioutil.WriteFile(yamlFile, []byte(yamlString), 0666)
+		result, err = kubectl.Kubectl("apply", "-f", yamlFile)
+		Expect(err).ToNot(HaveOccurred(), fmt.Sprintf("Error when running kubectl: %s", result))
+	}
+}
+
+func uninstallNMStateOperator() {
+	By("Uninstalling kubernetes-nmstate-operator")
+	componentSource, err := GetComponentSource("nmstate")
+	Expect(err).ToNot(HaveOccurred(), "Error getting the component source")
+
+	// Create temp directory
+	tmpdir, err := ioutil.TempDir("", "operator-test")
+	Expect(err).ToNot(HaveOccurred(), "Error creating temporary dir")
+	manifests := []string{"operator", "role_binding", "role", "service_account", "namespace"}
+	for _, manifest := range manifests {
+		yamlString, err := parseManifest(fmt.Sprintf("https://raw.githubusercontent.com/nmstate/kubernetes-nmstate/%s/deploy/operator/%s.yaml", componentSource.Metadata, manifest), componentSource.Metadata)
+		Expect(err).ToNot(HaveOccurred(), fmt.Sprintf("Error parsing manifest file to string: %s", manifest))
+
+		yamlFile := filepath.Join(tmpdir, fmt.Sprintf("%s.yaml", manifest))
+		ioutil.WriteFile(yamlFile, []byte(yamlString), 0666)
+		result, err := kubectl.Kubectl("delete", "-f", yamlFile)
+		Expect(err).ToNot(HaveOccurred(), fmt.Sprintf("Error when running kubectl: %s", result))
+	}
+	result, err := kubectl.Kubectl("delete", "-f", fmt.Sprintf("https://raw.githubusercontent.com/nmstate/kubernetes-nmstate/%s/deploy/crds/nmstate.io_nmstates.yaml", componentSource.Metadata))
+	Expect(err).ToNot(HaveOccurred(), "Error deleting CRD: %s", result)
+}
+
+func parseManifest(url string, tag string) (string, error) {
+	resp, err := http.Get(url)
+	if err != nil {
+		return "", errors.Wrapf(err, "Could not get url: %s", url)
+	}
+
+	defer resp.Body.Close()
+	body, err := ioutil.ReadAll(resp.Body)
+	if err != nil {
+		return "", errors.Wrapf(err, "Error reading body of url: %s", url)
+	}
+	var tmpl *template.Template
+	tmpl = template.Must(template.New("manifest").Parse(string(body)))
+
+	data := struct {
+		OperatorNamespace  string
+		OperatorImage      string
+		OperatorPullPolicy string
+		HandlerNamespace   string
+		HandlerImage       string
+		HandlerPullPolicy  string
+	}{
+		OperatorNamespace:  "nmstate",
+		OperatorImage:      fmt.Sprintf("quay.io/nmstate/kubernetes-nmstate-operator:%s", tag),
+		OperatorPullPolicy: "Always",
+		HandlerNamespace:   "nmstate",
+		HandlerImage:       fmt.Sprintf("quay.io/nmstate/kubernetes-nmstate-handler:%s", tag),
+		HandlerPullPolicy:  "Always",
+	}
+	var out bytes.Buffer
+	err = tmpl.Execute(&out, data)
+	if err != nil {
+		return "", errors.Wrapf(err, "Error parsing template")
+	}
+	return out.String(), nil
+}
+
 func testConfigCreate(gvk schema.GroupVersionKind, configSpec cnao.NetworkAddonsConfigSpec, components []Component) {
 	checkConfigChange(gvk, components, func() {
 		CreateConfig(gvk, configSpec)
